# Unix SMB/CIFS samba-tool-plus command group management module.

# Copyright (C) Paul Wolneykien <manowar@altlinux.org> 2017.
#
# Based on netcmd/user module by
#   Jelmer Vernooij <jelmer@samba.org> and
#   Andrew Tridgell.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import samba.getopt as options
from samba.auth import system_session

from netcmdplus.version import VersionOptions
from netcmdplus.samdb import SamDBPlus

from samba.netcmd import ( CommandError )

from samba.netcmd.group import ( cmd_group, cmd_group_add, security_group, distribution_group )

from samba.dsdb import (
    GTYPE_SECURITY_GLOBAL_GROUP,
    GTYPE_DISTRIBUTION_GLOBAL_GROUP,
)


class cmd_groupplus_update(cmd_group_add):
    """Updates group account parameters."""

    synopsis = "%prog <groupname> <options>"
    takes_optiongroups = cmd_group_add.takes_optiongroups
    takes_optiongroups["versionopts"] = VersionOptions

    def run(self, groupname, credopts=None, sambaopts=None,
            versionopts=None, H=None, groupou=None, group_scope=None,
            group_type=None, description=None, mail_address=None,
            notes=None, gid_number=None, nis_domain=None):

        lp = sambaopts.get_loadparm()
        creds = credopts.get_credentials(lp, fallback_machine=True)

        if (group_type or "Security") == "Security":
            gtype = security_group.get(group_scope, GTYPE_SECURITY_GLOBAL_GROUP)
        else:
            gtype = distribution_group.get(group_scope, GTYPE_DISTRIBUTION_GLOBAL_GROUP)

        try:
            samdb = SamDBPlus(url=H, session_info=system_session(),
                              credentials=creds, lp=lp)
            samdb.groupmod(groupname, groupou=groupou,
                           grouptype=gtype, description=description,
                           mailaddress=mail_address, notes=notes,
                           gidnumber=gid_number, nisdomain=nis_domain)
        except Exception, e:
            # FIXME: catch more specific exception
            raise CommandError('Failed to modify group "%s"' % groupname, e)
        self.outf.write("Updated group %s\n" % groupname)

class cmd_groupplus(cmd_group):
    """Extended group management."""

    subcommands = cmd_group.subcommands
    subcommands["update"] = cmd_groupplus_update()
