# Unix SMB/CIFS samba-tool-plus command user management module.

# Copyright (C) Paul Wolneykien <manowar@altlinux.org> 2017.
#
# Based on netcmd/user module by
#   Jelmer Vernooij <jelmer@samba.org> and
#   Theresa Halloran <theresahalloran@gmail.com>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import samba.getopt as options
from samba.auth import system_session

from netcmdplus.version import VersionOptions
from netcmdplus.samdb import SamDBPlus

from samba.netcmd import ( CommandError )

from samba.netcmd.user import ( cmd_user, cmd_user_create )

class cmd_userplus_update(cmd_user_create):
    """Updates user account parameters."""
    
    synopsis = "%prog <username> <options>"
    takes_optiongroups = cmd_user_create.takes_optiongroups
    takes_optiongroups["versionopts"] = VersionOptions

    def run(self, username, password=None, credopts=None, sambaopts=None,
            versionopts=None, H=None, must_change_at_next_login=False,
            random_password=False, use_username_as_cn=False, userou=None,
            surname=None, given_name=None, initials=None, profile_path=None,
            script_path=None, home_drive=None, home_directory=None,
            job_title=None, department=None, company=None, description=None,
            mail_address=None, internet_address=None, telephone_number=None,
            physical_delivery_office=None, rfc2307_from_nss=False,
            nis_domain=None, unix_home=None, uid=None, uid_number=None,
            gid_number=None, gecos=None, login_shell=None,
            smartcard_required=False):

        lp = sambaopts.get_loadparm()
        creds = credopts.get_credentials(lp)
        
        try:
            samdb = SamDBPlus(url=H, session_info=system_session(),
                              credentials=creds, lp=lp)
            samdb.usermod(username, password=password,
                          force_password_change_at_next_login_req=must_change_at_next_login,
                          useusernameascn=use_username_as_cn, userou=userou,
                          surname=surname, givenname=given_name,
                          initials=initials, profilepath=profile_path,
                          homedrive=home_drive, scriptpath=script_path,
                          homedirectory=home_directory,
                          jobtitle=job_title, department=department,
                          company=company, description=description,
                          mailaddress=mail_address,
                          internetaddress=internet_address,
                          telephonenumber=telephone_number,
                          physicaldeliveryoffice=physical_delivery_office,
                          nisdomain=nis_domain, unixhome=unix_home, uid=uid,
                          uidnumber=uid_number, gidnumber=gid_number,
                          gecos=gecos, loginshell=login_shell,
                          smartcard_required=smartcard_required)
        except Exception, e:
            raise CommandError("Failed to modify user '%s': " % username, e)

        self.outf.write("User account '%s' updated successfully\n" % username)

class cmd_userplus(cmd_user):
    """Extended user management."""
    
    subcommands = cmd_user.subcommands
    subcommands["update"] = cmd_userplus_update()
